@@ -25,6 +25,8 @@
 #'  status to color them, or \code{NULL}.
 #' @param replace When a choice is dragged in a target container already
 #'  containing a choice, does the later be replaced by the new one ?
+#' @param dragulaOpts Options passed to dragula JS library.
+#' @param boxStyle CSS style string to customize source and target container.
 #' @param width Width of the input.
 #' @param height Height of each boxes, the total input height is this parameter X 2.
 #' 
@@ -74,7 +76,10 @@ dragulaInput <- function(inputId, sourceLabel, targetsLabels,
                          targetsIds = NULL,
                          choices = NULL, choiceNames = NULL,
                          choiceValues = NULL, status = "primary", 
-                         replace = FALSE, badge = TRUE, width = NULL, height = "200px") {
+                         replace = FALSE, badge = TRUE,
+                         dragulaOpts = list(),
+                         boxStyle = NULL,
+                         width = NULL, height = "200px") {
   
   args <- normalizeChoicesArgs(choices, choiceNames, choiceValues)
   
@@ -84,22 +89,23 @@ dragulaInput <- function(inputId, sourceLabel, targetsLabels,
     stopifnot(length(targetsLabels) == length(targetsIds))
   }
   
-  replace_targets <- targetsIds
+  replaceTargets <- targetsIds
   if (is.numeric(replace)) {
-    replace_targets <- targetsIds[replace]
+    replaceTargets <- targetsIds[replace]
     replace <- TRUE
   } else {
     stopifnot(is.logical(replace))
   }
-  replace_targets <- paste0(inputId, "-target-", replace_targets)
+  replaceTargets <- paste0(inputId, "-target-", replaceTargets)
   
   target_list <- lapply(
     X = seq_along(targetsLabels),
     FUN = function(i) {
       tags$div(
         style = "height: 95%; margin: 0;",
-        class = "box-dad xyvar", id = paste(inputId, "target", targetsIds[i], sep = "-"),
-        # tags$em(tags$b(targetsLabels[i], class = "label-background"))
+        style = boxStyle,
+        class = "box-dad xyvar",
+        id = paste(inputId, "target", targetsIds[i], sep = "-"),
         style = make_bg_svg(targetsLabels[i])
       )
     }
@@ -114,35 +120,34 @@ dragulaInput <- function(inputId, sourceLabel, targetsLabels,
   target_list$cellWidths <- tgw
   
   tagList(
-    singleton(
-      tags$head(
-        tags$script(src = "esquisse/dragula/dragula.min.js"),
-        tags$link(rel = "stylesheet", type = "text/css", href = "esquisse/dragula/dragula.min.css"),
-        tags$script(src = "esquisse/dragula/dragula-bindings.js"),
-        tags$link(rel = "stylesheet", type = "text/css", href = "esquisse/styles-dad.css")
-      )
-    ),
+    html_dependency_dragula(),
     tags$div(
       class="form-group shiny-input-container shiny-input-dragula shiny-input-container-inline",
-      style = if(!is.null(width)) paste("width:", htmltools::validateCssUnit(width), ";"),
-      style = if(!is.null(height)) paste("height:", htmltools::validateCssUnit(height), ";"),
-      id = inputId, #style = "height: 200px;", 
-      `data-source` = jsonlite::toJSON(paste(inputId, "source", sep = "-")),
-      `data-targets` = jsonlite::toJSON(paste(inputId, "target", targetsIds, sep = "-")),
-      `data-replace` = tolower(replace),
-      `data-replace-ids` = jsonlite::toJSON(x = replace_targets),
+      style = if(!is.null(width)) paste("width:", validateCssUnit(width), ";"),
+      style = if(!is.null(height)) paste("height:", validateCssUnit(height), ";"),
+      id = inputId, 
       tags$div(
-        style = "height: 50%; width: 99.5%; padding-right: 0; padding-left: 0; margin-right: 0; margin-left: 0;",
-        class = "box-dad",
+        class = "container-drag-source",
+        style = boxStyle,
         style = make_bg_svg(sourceLabel),
-        # tags$em(tags$b(sourceLabel, class = "label-background")),
         tags$div(
           id = paste(inputId, "source", sep = "-"), 
           style = "margin: 5px; width: 100%; min-height: 15px; margin-right: 0;",
           makeDragulaChoices(inputId = inputId, args = args, status = status, badge = badge)
         )
       ),
-      do.call(splitLayout, target_list)
+      do.call(splitLayout, target_list),
+      tags$script(
+        type = "application/json",
+        `data-for` = inputId,
+        toJSON(list(
+          source = list1(paste(inputId, "source", sep = "-")),
+          targets = list1(paste(inputId, "target", targetsIds, sep = "-")),
+          replace = replace,
+          replaceIds = list1(replaceTargets),
+          options = dragulaOpts
+        ), auto_unbox = TRUE, json_verbatim = TRUE)
+      )
     )
   )
 }
@@ -259,7 +264,7 @@ updateDragulaInput <- function(session, inputId, choices = NULL, choiceNames = N
                                choiceValues = NULL, badge = TRUE, status = "primary") {
   args <- normalizeChoicesArgs(choices, choiceNames, choiceValues)
   choices <- htmltools::doRenderTags(makeDragulaChoices(
-    inputId = inputId, args = args, status = status, badge = badge
+    inputId = session$ns(inputId), args = args, status = status, badge = badge
   ))
   message <- list(choices = choices)
   session$sendInputMessage(inputId, message)
@@ -287,3 +292,19 @@ makeDragulaChoices <- function(inputId, args, status = NULL, badge = TRUE) {
 
 
 
+#' @importFrom htmltools htmlDependency
+html_dependency_dragula <- function() {
+  htmlDependency(
+    name = "esquisse-dragula", 
+    version = "0.1.0", 
+    src = c(file = "assets", href = "esquisse"),
+    package = "esquisse",
+    script = c("dragula/dragula.min.js", "dragula/dragula-bindings.js"),
+    stylesheet = c("dragula/dragula.min.css", "styles-dad.css"), 
+    all_files = FALSE
+  )
+}
+
+
+
+
