@@ -15,7 +15,15 @@
 `%nin%` <- Negate(`%in%`)
 
 
-
+list1 <- function(x) {
+  if (is.null(x))
+    return(x)
+  if (length(x) == 1 & !is.list(x)) {
+    list(x)
+  } else {
+    x
+  }
+}
 
 
 # utilities borrowed from shiny
